==> haskell-reducers-3.12.3-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.3
id: reducers-3.12.3-LNKi4u90qQkBWVDQPiW0Wq
key: reducers-3.12.3-LNKi4u90qQkBWVDQPiW0Wq
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework.
category: Data, Math, Numerical, Semigroups
abi: 3b2c3d54db7df8b0deefa3809d800c63
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
import-dirs: /usr/lib/ghc-8.6.5/site-local/reducers-3.12.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/reducers-3.12.3
hs-libraries: HSreducers-3.12.3-LNKi4u90qQkBWVDQPiW0Wq
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    fingertree-0.1.4.2-6sV9WbgA4IlAhQCrY6F3m6
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.2-E8bBgioebzyBd6Df4R8d9J text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.3-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.3
id: reducers-3.12.3-DZVmrUdu3iDGS1PZURh1lp
key: reducers-3.12.3-DZVmrUdu3iDGS1PZURh1lp
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework.
category: Data, Math, Numerical, Semigroups
abi: f5c9b63bc62d86f3864126e9caa758d4
exposed: True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
import-dirs: /usr/lib/ghc-8.6.5/site-local/reducers-3.12.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/reducers-3.12.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/reducers-3.12.3
hs-libraries: HSreducers-3.12.3-DZVmrUdu3iDGS1PZURh1lp
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    fingertree-0.1.4.2-AeCRrqADlEjJHJN3ubSCWe
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    semigroupoids-5.3.2-51DW0PUiIsxG0u3N2JZbgy text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-9wTHYlaSuHyGA5dBBp2WV8
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
